@@ -15,7 +15,7 @@ async fn index(
 ) -> Result<Response, Response> {
     let health_check = status::HealthCheck::new()?;
     match health_check.firstboot_ok {
-        false => Ok(Response::Template(Template::render("status", health_check))),
+        false => Ok(Response::Redirect(Redirect::to("/status"))),
         true => {
             let maybe_config = auth::is_auth_valid(jar, config_file)?;
             match maybe_config {
